@@ -8,7 +8,6 @@
  *  compress and decompress chunks
  */
 #include <postgres.h>
-#include "guc.h"
 #include <access/tableam.h>
 #include <access/xact.h>
 #include <catalog/dependency.h>
@@ -45,6 +44,8 @@
 #include "debug_point.h"
 #include "error_utils.h"
 #include "errors.h"
+#include "extension_constants.h"
+#include "guc.h"
 #include "hypercore/hypercore_handler.h"
 #include "hypercore/utils.h"
 #include "hypercube.h"
@@ -254,7 +255,7 @@ compresschunkcxt_init(CompressChunkCxt *cxt, Cache *hcache, Oid hypertable_relid
 	compress_ht = ts_hypertable_get_by_id(srcht->fd.compressed_hypertable_id);
 	if (compress_ht == NULL)
 		ereport(ERROR,
-				(errcode(ERRCODE_INTERNAL_ERROR),
+				(errcode(ERRCODE_TS_HYPERTABLE_NOT_EXIST),
 				 errmsg("missing columnstore-enabled hypertable")));
 	/* user has to be the owner of the compression table too */
 	ts_hypertable_permissions_check(compress_ht->main_table_relid, GetUserId());
@@ -534,13 +535,6 @@ compress_chunk_impl(Oid hypertable_relid, Oid chunk_relid)
 											  cstat.rowcnt_post_compression,
 											  cstat.rowcnt_frozen);
 
-		/* Copy chunk constraints (including fkey) to compressed chunk.
-		 * Do this after compressing the chunk to avoid holding strong, unnecessary locks on the
-		 * referenced table during compression.
-		 */
-		ts_chunk_constraints_create(cxt.compress_ht, compress_ht_chunk);
-		ts_trigger_create_all_on_chunk(compress_ht_chunk);
-
 		/* Detect and emit warning if poor compression ratio is found */
 		float compression_ratio = ((float) before_size.total_size / after_size.total_size);
 		float POOR_COMPRESSION_THRESHOLD = 1.0;
@@ -611,7 +605,7 @@ decompress_chunk_impl(Chunk *uncompressed_chunk, bool if_compressed)
 		ts_hypertable_get_by_id(uncompressed_hypertable->fd.compressed_hypertable_id);
 	if (compressed_hypertable == NULL)
 		ereport(ERROR,
-				(errcode(ERRCODE_INTERNAL_ERROR),
+				(errcode(ERRCODE_TS_HYPERTABLE_NOT_EXIST),
 				 errmsg("missing columnstore-enabled hypertable")));
 
 	if (uncompressed_chunk->fd.hypertable_id != uncompressed_hypertable->fd.id)
@@ -755,10 +749,6 @@ tsl_create_compressed_chunk(PG_FUNCTION_ARGS)
 	compress_ht_chunk = create_compress_chunk(cxt.compress_ht, cxt.srcht_chunk, chunk_table);
 	EventTriggerAlterTableEnd();
 
-	/* Copy chunk constraints (including fkey) to compressed chunk */
-	ts_chunk_constraints_create(cxt.compress_ht, compress_ht_chunk);
-	ts_trigger_create_all_on_chunk(compress_ht_chunk);
-
 	/* Insert empty stats to compression_chunk_size */
 	compression_chunk_size_catalog_insert(cxt.srcht_chunk->fd.id,
 										  &uncompressed_size,
@@ -860,8 +850,8 @@ compress_hypercore(Chunk *chunk, bool rel_is_hypercore, UseAccessMethod useam,
 		const RangeVar *rv = makeRangeVar(relschema, relname, -1);
 		/* Do quick migration to hypercore of already compressed data by
 		 * simply changing the access method to hypercore in pg_am. */
-		hypercore_set_am(rv);
-		hypercore_set_reloptions(chunk);
+		hypercore_set_am(rv, TS_HYPERCORE_TAM_NAME);
+		hypercore_set_compressed_autovacuum_reloption(chunk, false);
 		return chunk->table_id;
 	}
 
@@ -1028,11 +1018,13 @@ tsl_decompress_chunk(PG_FUNCTION_ARGS)
 
 	if (!ht->fd.compressed_hypertable_id)
 		ereport(ERROR,
-				(errcode(ERRCODE_INTERNAL_ERROR),
+				(errcode(ERRCODE_TS_HYPERTABLE_NOT_EXIST),
 				 errmsg("missing columnstore-enabled hypertable")));
 
 	if (ts_is_hypercore_am(uncompressed_chunk->amoid))
+	{
 		set_access_method(uncompressed_chunk_id, "heap");
+	}
 	else if (!ts_chunk_is_compressed(uncompressed_chunk))
 	{
 		ereport((if_compressed ? NOTICE : ERROR),
@@ -1093,3 +1085,10 @@ get_compressed_chunk_index_for_recompression(Chunk *uncompressed_chunk)
 
 	return index_oid;
 }
+
+Chunk *
+tsl_compression_chunk_create(Hypertable *compressed_ht, Chunk *src_chunk)
+{
+	/* Create a new compressed chunk */
+	return create_compress_chunk(compressed_ht, src_chunk, InvalidOid);
+}
